﻿using SecuritySystemContracts.BindingModels;
using SecuritySystemContracts.ViewModels;
using SecuritySystemDataModels.Models;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using System.Runtime.Serialization;

namespace SecuritySystemDatabaseImplement.Models
{
    [DataContract]
    public class Client : IClientModel
    {
        [DataMember]
        public int Id { get; private set; }
        [DataMember]
        [Required]
        public string ClientFIO { get; private set; } = string.Empty;
        [DataMember]
        [Required]
        public string Email { get; private set; } = string.Empty;
        [DataMember]
        [Required]
        public string Password { get; private set; } = string.Empty;
        [ForeignKey("ClientId")]
        public virtual List<Order> Orders { get; set; } = new();
        [ForeignKey("ClientId")]
        public virtual List<MessageInfo> MessageInfos { get; set; } = new();
        public static Client? Create(ClientBindingModel model)
        {
            if (model == null)
            {
                return null;
            }
            return new Client()
            {
                Id = model.Id,
                Email = model.Email,
                Password = model.Password,
                ClientFIO = model.ClientFIO
            };
        }
        public static Client Create(ClientViewModel model)
        {
            return new Client
            {
                Id = model.Id,
                Email = model.Email,
                Password = model.Password,
                ClientFIO = model.ClientFIO
            };
        }
        public void Update(ClientBindingModel model)
        {
            if (model == null)
            {
                return;
            }
            Email = model.Email;
            Password = model.Password;
            ClientFIO = model.ClientFIO;
        }
        public ClientViewModel GetViewModel => new()
        {
            Id = Id,
            Email = Email,
            Password = Password,
            ClientFIO = ClientFIO
        };
    }
}
