﻿using SecuritySystemContracts.BindingModels;
using SecuritySystemContracts.ViewModels;
using SecuritySystemDataModels.Models;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using System.Runtime.Serialization;

namespace SecuritySystemDatabaseImplement.Models
{
    [DataContract]
    public class Implementer : IImplementerModel
    {
        [DataMember]
        public int Id { get; private set; }
        [DataMember]
        [Required]
        public string ImplementerFIO { get; private set; } = string.Empty;
        [DataMember]
        [Required]
        public string Password { get; private set; } = string.Empty;
        [DataMember]
        [Required]
        public int Qualification { get; private set; }
        [DataMember]
        [Required]
        public int WorkExperience { get; private set; }
        [ForeignKey("ImplementerId")]
        public virtual List<Order> Orders { get; private set; } = new();
        public static Implementer? Create(ImplementerBindingModel model)
        {
            if (model == null)
            {
                return null;
            }
            return new Implementer()
            {
                Id = model.Id,
                Qualification = model.Qualification,
                Password = model.Password,
                ImplementerFIO = model.ImplementerFIO,
                WorkExperience = model.WorkExperience
            };
        }
        public static Implementer Create(ImplementerViewModel model)
        {
            return new Implementer
            {
                Id = model.Id,
                Qualification = model.Qualification,
                Password = model.Password,
                ImplementerFIO = model.ImplementerFIO,
                WorkExperience = model.WorkExperience
            };
        }
        public void Update(ImplementerBindingModel model)
        {
            if (model == null)
            {
                return;
            }
            Qualification = model.Qualification;
            Password = model.Password;
            ImplementerFIO = model.ImplementerFIO;
            WorkExperience = model.WorkExperience;
        }
        public ImplementerViewModel GetViewModel => new()
        {
            Id = Id,
            Qualification = Qualification,
            Password = Password,
            ImplementerFIO = ImplementerFIO,
            WorkExperience = WorkExperience
        };
    }
}
