﻿using SecuritySystemContracts.BindingModels;
using SecuritySystemContracts.ViewModels;
using SecuritySystemDataModels.Enums;
using SecuritySystemDataModels.Models;
using System.ComponentModel.DataAnnotations;
using System.Runtime.Serialization;

namespace SecuritySystemDatabaseImplement.Models
{
    [DataContract]
    public class Order : IOrderModel
    {
        [DataMember]
        public int Id { get; private set; }
        [DataMember]
        [Required]
        public int SecureId { get; private set; }
        [DataMember]
        [Required]
        public int ClientId { get; private set; }
        [DataMember]
        public int? ImplementerId {  get; private set; }
        [DataMember]
        [Required]
        public int Count { get; private set; }
        [DataMember]
        [Required]
        public double Sum { get; private set; }
        [DataMember]
        [Required]
        public OrderStatus Status { get; private set; } = OrderStatus.Неизвестен;
        [DataMember]
        [Required]
        public DateTime DateCreate { get; private set; } = DateTime.Now;
        [DataMember]
        public DateTime? DateImplement { get; private set; }
        public virtual Secure Secure { get; private set; }
        public virtual Client Client { get; private set; }
        public virtual Implementer? Implementer { get; private set; }
        public static Order? Create(OrderBindingModel? model)
        {
            if (model == null)
            {
                return null;
            }
            return new Order
            {
                SecureId = model.SecureId,
                ClientId = model.ClientId,
                Count = model.Count,
                Sum = model.Sum,
                Status = model.Status,
                DateCreate = model.DateCreate,
                DateImplement = model.DateImplement,
                Id = model.Id,
                ImplementerId = model.ImplementerId
            };
        }

        public void Update(OrderBindingModel? model)
        {
            if (model == null)
            {
                return;
            }
            Status = model.Status;
            DateImplement = model.DateImplement;
            ImplementerId = model.ImplementerId;
        }

        public OrderViewModel GetViewModel => new()
        {
            SecureId = SecureId,
            ClientId = ClientId,
            Count = Count,
            Sum = Sum,
            DateCreate = DateCreate,
            DateImplement = DateImplement,
            Id = Id,
            Status = Status,
            SecureName = Secure.SecureName,
            ClientFIO = Client.ClientFIO,
            ImplementerId = ImplementerId,
            ImplementerFIO = Implementer?.ImplementerFIO ?? string.Empty
        };
    }
}
