﻿using SecuritySystemContracts.BindingModels;
using SecuritySystemContracts.ViewModels;
using SecuritySystemDataModels.Enums;
using SecuritySystemDataModels.Models;

namespace SecuritySystemListImplement.Models
{
    public class Order : IOrderModel
    {
        public int SecureId { get; private set; }
        public int ClientId { get; private set; }
        public int Count { get; private set; }
        public double Sum { get; private set; }
        public int? ImplementerId { get; private set; }
        public OrderStatus Status { get; private set; } = OrderStatus.Неизвестен;
        public DateTime DateCreate { get; private set; } = DateTime.Now;
        public DateTime? DateImplement { get; private set; }
        public int Id { get; private set; }
        public static Order? Create(OrderBindingModel? model)
        {
            if (model == null)
            {
                return null;
            }
            return new Order
            {
                Id = model.Id,
                SecureId = model.SecureId,
                Count = model.Count,
                Sum = model.Sum,
                Status = model.Status,
                DateCreate = model.DateCreate,
                DateImplement = model.DateImplement,
                ImplementerId = model.ImplementerId,
            };
        }
        public void Update(OrderBindingModel? model)
        {
            if (model == null)
            {
                return;
            }
            Status = model.Status;
            DateImplement = model.DateImplement;
            ImplementerId = model.ImplementerId;
        }
        public OrderViewModel GetViewModel => new()
        {
            SecureId = SecureId,
            Count = Count,
            Sum = Sum,
            DateCreate = DateCreate,
            DateImplement = DateImplement,
            Id = Id,
            Status = Status,
            ImplementerId = ImplementerId,
        };
    }
}
